@@ -2,16 +2,10 @@ use std::path::{Path, PathBuf};
 
 use url::Url;
 
-use cache_key::{digest, CanonicalUrl};
+use cache_key::{cache_digest, CanonicalUrl};
 use distribution_types::IndexUrl;
 
-#[allow(unused_imports)] // For rustdoc
-use crate::CacheBucket;
-
 /// Cache wheels and their metadata, both from remote wheels and built from source distributions.
-///
-/// Use [`WheelCache::remote_wheel_dir`] for remote wheel metadata caching and
-/// [`WheelCache::built_wheel_dir`] for built source distributions metadata caching.
 #[derive(Debug, Clone)]
 pub enum WheelCache<'a> {
     /// Either PyPI or an alternative index, which we key by index URL.
@@ -20,6 +14,8 @@ pub enum WheelCache<'a> {
     Url(&'a Url),
     /// A path dependency, which we key by URL.
     Path(&'a Url),
+    /// An editable dependency, which we key by URL.
+    Editable(&'a Url),
     /// A Git dependency, which we key by URL and SHA.
     ///
     /// Note that this variant only exists for source distributions; wheels can't be delivered
@@ -28,33 +24,32 @@ pub enum WheelCache<'a> {
 }
 
 impl<'a> WheelCache<'a> {
-    fn bucket(&self) -> PathBuf {
+    /// The root directory for a cache bucket.
+    pub fn root(&self) -> PathBuf {
         match self {
             WheelCache::Index(IndexUrl::Pypi(_)) => WheelCacheKind::Pypi.root(),
             WheelCache::Index(url) => WheelCacheKind::Index
                 .root()
-                .join(digest(&CanonicalUrl::new(url))),
+                .join(cache_digest(&CanonicalUrl::new(url))),
             WheelCache::Url(url) => WheelCacheKind::Url
                 .root()
-                .join(digest(&CanonicalUrl::new(url))),
+                .join(cache_digest(&CanonicalUrl::new(url))),
             WheelCache::Path(url) => WheelCacheKind::Path
                 .root()
-                .join(digest(&CanonicalUrl::new(url))),
+                .join(cache_digest(&CanonicalUrl::new(url))),
+            WheelCache::Editable(url) => WheelCacheKind::Editable
+                .root()
+                .join(cache_digest(&CanonicalUrl::new(url))),
             WheelCache::Git(url, sha) => WheelCacheKind::Git
                 .root()
-                .join(digest(&CanonicalUrl::new(url)))
+                .join(cache_digest(&CanonicalUrl::new(url)))
                 .join(sha),
         }
     }
 
-    /// Metadata of a remote wheel. See [`CacheBucket::Wheels`]
-    pub fn remote_wheel_dir(&self, package_name: impl AsRef<Path>) -> PathBuf {
-        self.bucket().join(package_name)
-    }
-
-    /// Metadata of a built source distribution. See [`CacheBucket::BuiltWheels`]
-    pub fn built_wheel_dir(&self, filename: impl AsRef<Path>) -> PathBuf {
-        self.bucket().join(filename)
+    /// A subdirectory in a bucket for wheels for a specific package.
+    pub fn wheel_dir(&self, package_name: impl AsRef<Path>) -> PathBuf {
+        self.root().join(package_name)
     }
 }
 
@@ -68,6 +63,8 @@ pub(crate) enum WheelCacheKind {
     Url,
     /// A cache of data from a local path.
     Path,
+    /// A cache of data from an editable URL.
+    Editable,
     /// A cache of data from a Git repository.
     Git,
 }
@@ -79,6 +76,7 @@ impl WheelCacheKind {
             Self::Index => "index",
             Self::Url => "url",
             Self::Path => "path",
+            Self::Editable => "editable",
             Self::Git => "git",
         }
     }
