@@ -1,7 +1,11 @@
 use fs2::FileExt;
 use std::fmt::Display;
+use std::io;
 use std::path::{Path, PathBuf};
+use std::pin::Pin;
+use std::task::{Context, Poll};
 use tempfile::NamedTempFile;
+use tokio::io::{AsyncRead, ReadBuf};
 use tracing::{debug, error, info, trace, warn};
 
 pub use crate::path::*;
@@ -387,3 +391,32 @@ impl Drop for LockedFile {
         }
     }
 }
+
+/// An asynchronous reader that reports progress as bytes are read.
+pub struct ProgressReader<Reader: AsyncRead + Unpin, Callback: Fn(usize) + Unpin> {
+    reader: Reader,
+    callback: Callback,
+}
+
+impl<Reader: AsyncRead + Unpin, Callback: Fn(usize) + Unpin> ProgressReader<Reader, Callback> {
+    /// Create a new [`ProgressReader`] that wraps another reader.
+    pub fn new(reader: Reader, callback: Callback) -> Self {
+        Self { reader, callback }
+    }
+}
+
+impl<Reader: AsyncRead + Unpin, Callback: Fn(usize) + Unpin> AsyncRead
+    for ProgressReader<Reader, Callback>
+{
+    fn poll_read(
+        mut self: Pin<&mut Self>,
+        cx: &mut Context<'_>,
+        buf: &mut ReadBuf<'_>,
+    ) -> Poll<io::Result<()>> {
+        Pin::new(&mut self.as_mut().reader)
+            .poll_read(cx, buf)
+            .map_ok(|()| {
+                (self.callback)(buf.filled().len());
+            })
+    }
+}
