@@ -201,6 +201,7 @@ mod tests {
             version: &PythonVersion,
             implementation: ImplementationName,
             system: bool,
+            free_threaded: bool,
         ) -> Result<()> {
             let json = indoc! {r##"
                     {
@@ -251,7 +252,7 @@ mod tests {
                             "scripts": "bin"
                         },
                         "pointer_size": "64",
-                        "gil_disabled": true
+                        "gil_disabled": {FREE_THREADED}
                     }
                 "##};
 
@@ -268,6 +269,7 @@ mod tests {
                 )
                 .replace("{FULL_VERSION}", &version.to_string())
                 .replace("{VERSION}", &version.without_patch().to_string())
+                .replace("{FREE_THREADED}", &free_threaded.to_string())
                 .replace("{IMPLEMENTATION}", (&implementation).into());
 
             fs_err::create_dir_all(path.parent().unwrap())?;
@@ -327,6 +329,7 @@ mod tests {
                 &PythonVersion::from_str(version).expect("Test uses valid version"),
                 ImplementationName::default(),
                 true,
+                false,
             )
         }
 
@@ -366,6 +369,7 @@ mod tests {
                     &PythonVersion::from_str(version).unwrap(),
                     *implementation,
                     *system,
+                    false,
                 )?;
             }
             Ok(())
@@ -385,6 +389,7 @@ mod tests {
                     .expect("A valid Python version is used for tests"),
                 ImplementationName::default(),
                 false,
+                false,
             )?;
             ChildPath::new(path.as_ref().join("pyvenv.cfg")).touch()?;
             Ok(())
@@ -406,6 +411,7 @@ mod tests {
                     .expect("A valid Python version is used for tests"),
                 ImplementationName::default(),
                 true,
+                false,
             )?;
             ChildPath::new(path.as_ref().join("pyvenv.cfg")).touch()?;
             Ok(())
@@ -537,6 +543,7 @@ mod tests {
             &PythonVersion::from_str("3.12.1").unwrap(),
             ImplementationName::default(),
             true,
+            false,
         )?;
 
         let python = context.run(|| {
@@ -604,6 +611,7 @@ mod tests {
             &PythonVersion::from_str("3.12.1").unwrap(),
             ImplementationName::default(),
             true,
+            false,
         )?;
 
         let python = context.run(|| {
@@ -1169,6 +1177,7 @@ mod tests {
             ImplementationName::CPython,
             // Note we mark this as a system interpreter instead of a virtual environment
             true,
+            false,
         )?;
 
         let python = context.run_with_vars(
@@ -1289,6 +1298,7 @@ mod tests {
             ImplementationName::CPython,
             // Note we mark this as a system interpreter instead of a virtual environment
             true,
+            false,
         )?;
 
         let python = context.run_with_vars(
@@ -1461,6 +1471,7 @@ mod tests {
             &PythonVersion::from_str("3.10.0").unwrap(),
             ImplementationName::default(),
             true,
+            false,
         )?;
 
         let python = context.run(|| {
@@ -1504,6 +1515,7 @@ mod tests {
             &PythonVersion::from_str("3.10.0").unwrap(),
             ImplementationName::default(),
             true,
+            false,
         )?;
 
         let python = context.run(|| {
@@ -1609,6 +1621,7 @@ mod tests {
             &PythonVersion::from_str("3.10.0").unwrap(),
             ImplementationName::default(),
             true,
+            false,
         )?;
         let python = context.run(|| {
             find_python_installation(
@@ -1701,6 +1714,7 @@ mod tests {
             &PythonVersion::from_str("3.10.0").unwrap(),
             ImplementationName::default(),
             true,
+            false,
         )?;
         context.add_to_search_path(context.tempdir.child("foo").to_path_buf());
 
@@ -1740,6 +1754,7 @@ mod tests {
             &PythonVersion::from_str("3.10.0").unwrap(),
             ImplementationName::default(),
             false, // Not a system interpreter
+            false,
         )?;
         context.add_to_search_path(context.tempdir.child("foo").to_path_buf());
 
@@ -1778,7 +1793,7 @@ mod tests {
         })?;
         assert!(
             matches!(result, Err(PythonNotFound { .. })),
-            "We should not the pypy interpreter if not named `python` or requested; got {result:?}"
+            "We should not find the pypy interpreter if not named `python` or requested; got {result:?}"
         );
 
         // But we should find it
@@ -1983,124 +1998,6 @@ mod tests {
         Ok(())
     }
 
-    #[test]
-    fn find_python_pypy_prefers_executable_with_implementation_name() -> Result<()> {
-        let mut context = TestContext::new()?;
-
-        // We should prefer `pypy` executables over `python` executables in the same directory
-        // even if they are both pypy
-        TestContext::create_mock_interpreter(
-            &context.tempdir.join("python"),
-            &PythonVersion::from_str("3.10.0").unwrap(),
-            ImplementationName::PyPy,
-            true,
-        )?;
-        TestContext::create_mock_interpreter(
-            &context.tempdir.join("pypy"),
-            &PythonVersion::from_str("3.10.1").unwrap(),
-            ImplementationName::PyPy,
-            true,
-        )?;
-        context.add_to_search_path(context.tempdir.to_path_buf());
-
-        let python = context.run(|| {
-            find_python_installation(
-                &PythonRequest::parse("pypy@3.10"),
-                EnvironmentPreference::Any,
-                PythonPreference::OnlySystem,
-                &context.cache,
-            )
-        })??;
-        assert_eq!(
-            python.interpreter().python_full_version().to_string(),
-            "3.10.1",
-        );
-
-        // But `python` executables earlier in the search path will take precedence
-        context.reset_search_path();
-        context.add_python_interpreters(&[
-            (true, ImplementationName::PyPy, "python", "3.10.2"),
-            (true, ImplementationName::PyPy, "pypy", "3.10.3"),
-        ])?;
-        let python = context.run(|| {
-            find_python_installation(
-                &PythonRequest::parse("pypy@3.10"),
-                EnvironmentPreference::Any,
-                PythonPreference::OnlySystem,
-                &context.cache,
-            )
-        })??;
-        assert_eq!(
-            python.interpreter().python_full_version().to_string(),
-            "3.10.2",
-        );
-
-        Ok(())
-    }
-
-    #[test]
-    fn find_python_pypy_prefers_executable_with_version() -> Result<()> {
-        let mut context = TestContext::new()?;
-        TestContext::create_mock_interpreter(
-            &context.tempdir.join("pypy3.10"),
-            &PythonVersion::from_str("3.10.0").unwrap(),
-            ImplementationName::PyPy,
-            true,
-        )?;
-        TestContext::create_mock_interpreter(
-            &context.tempdir.join("pypy"),
-            &PythonVersion::from_str("3.10.1").unwrap(),
-            ImplementationName::PyPy,
-            true,
-        )?;
-        context.add_to_search_path(context.tempdir.to_path_buf());
-
-        let python = context.run(|| {
-            find_python_installation(
-                &PythonRequest::parse("pypy@3.10"),
-                EnvironmentPreference::Any,
-                PythonPreference::OnlySystem,
-                &context.cache,
-            )
-        })??;
-        assert_eq!(
-            python.interpreter().python_full_version().to_string(),
-            "3.10.0",
-            "We should prefer executables with the version number over those with implementation names"
-        );
-
-        let mut context = TestContext::new()?;
-        TestContext::create_mock_interpreter(
-            &context.tempdir.join("python3.10"),
-            &PythonVersion::from_str("3.10.0").unwrap(),
-            ImplementationName::PyPy,
-            true,
-        )?;
-        TestContext::create_mock_interpreter(
-            &context.tempdir.join("pypy"),
-            &PythonVersion::from_str("3.10.1").unwrap(),
-            ImplementationName::PyPy,
-            true,
-        )?;
-        context.add_to_search_path(context.tempdir.to_path_buf());
-
-        let python = context.run(|| {
-            find_python_installation(
-                &PythonRequest::parse("pypy@3.10"),
-                EnvironmentPreference::Any,
-                PythonPreference::OnlySystem,
-                &context.cache,
-            )
-        })??;
-        assert_eq!(
-            python.interpreter().python_full_version().to_string(),
-            "3.10.1",
-            "We should prefer an implementation name executable over a generic name with a version"
-        );
-
-        Ok(())
-    }
-
     #[test]
     fn find_python_graalpy() -> Result<()> {
         let mut context = TestContext::new()?;
@@ -2203,22 +2100,24 @@ mod tests {
     }
 
     #[test]
-    fn find_python_graalpy_prefers_executable_with_implementation_name() -> Result<()> {
+    fn find_python_prefers_generic_executable_over_implementation_name() -> Result<()> {
         let mut context = TestContext::new()?;
 
-        // We should prefer `graalpy` executables over `python` executables in the same directory
-        // even if they are both graalpy
+        // We prefer `python` executables over `graalpy` executables in the same directory
+        // if they are both GraalPy
         TestContext::create_mock_interpreter(
             &context.tempdir.join("python"),
             &PythonVersion::from_str("3.10.0").unwrap(),
             ImplementationName::GraalPy,
             true,
+            false,
         )?;
         TestContext::create_mock_interpreter(
             &context.tempdir.join("graalpy"),
             &PythonVersion::from_str("3.10.1").unwrap(),
             ImplementationName::GraalPy,
             true,
+            false,
         )?;
         context.add_to_search_path(context.tempdir.to_path_buf());
 
@@ -2232,10 +2131,10 @@ mod tests {
         })??;
         assert_eq!(
             python.interpreter().python_full_version().to_string(),
-            "3.10.1",
+            "3.10.0",
         );
 
-        // But `python` executables earlier in the search path will take precedence
+        // And `python` executables earlier in the search path will take precedence
         context.reset_search_path();
         context.add_python_interpreters(&[
             (true, ImplementationName::GraalPy, "python", "3.10.2"),
@@ -2254,6 +2153,196 @@ mod tests {
             "3.10.2",
         );
 
+        // But `graalpy` executables earlier in the search path will take precedence
+        context.reset_search_path();
+        context.add_python_interpreters(&[
+            (true, ImplementationName::GraalPy, "graalpy", "3.10.3"),
+            (true, ImplementationName::GraalPy, "python", "3.10.2"),
+        ])?;
+        let python = context.run(|| {
+            find_python_installation(
+                &PythonRequest::parse("graalpy@3.10"),
+                EnvironmentPreference::Any,
+                PythonPreference::OnlySystem,
+                &context.cache,
+            )
+        })??;
+        assert_eq!(
+            python.interpreter().python_full_version().to_string(),
+            "3.10.3",
+        );
+
+        Ok(())
+    }
+
+    #[test]
+    fn find_python_prefers_generic_executable_over_one_with_version() -> Result<()> {
+        let mut context = TestContext::new()?;
+        TestContext::create_mock_interpreter(
+            &context.tempdir.join("pypy3.10"),
+            &PythonVersion::from_str("3.10.0").unwrap(),
+            ImplementationName::PyPy,
+            true,
+            false,
+        )?;
+        TestContext::create_mock_interpreter(
+            &context.tempdir.join("pypy"),
+            &PythonVersion::from_str("3.10.1").unwrap(),
+            ImplementationName::PyPy,
+            true,
+            false,
+        )?;
+        context.add_to_search_path(context.tempdir.to_path_buf());
+
+        let python = context.run(|| {
+            find_python_installation(
+                &PythonRequest::parse("pypy@3.10"),
+                EnvironmentPreference::Any,
+                PythonPreference::OnlySystem,
+                &context.cache,
+            )
+        })??;
+        assert_eq!(
+            python.interpreter().python_full_version().to_string(),
+            "3.10.1",
+            "We should prefer the generic executable over one with the version number"
+        );
+
+        let mut context = TestContext::new()?;
+        TestContext::create_mock_interpreter(
+            &context.tempdir.join("python3.10"),
+            &PythonVersion::from_str("3.10.0").unwrap(),
+            ImplementationName::PyPy,
+            true,
+            false,
+        )?;
+        TestContext::create_mock_interpreter(
+            &context.tempdir.join("pypy"),
+            &PythonVersion::from_str("3.10.1").unwrap(),
+            ImplementationName::PyPy,
+            true,
+            false,
+        )?;
+        context.add_to_search_path(context.tempdir.to_path_buf());
+
+        let python = context.run(|| {
+            find_python_installation(
+                &PythonRequest::parse("pypy@3.10"),
+                EnvironmentPreference::Any,
+                PythonPreference::OnlySystem,
+                &context.cache,
+            )
+        })??;
+        assert_eq!(
+            python.interpreter().python_full_version().to_string(),
+            "3.10.0",
+            "We should prefer the generic name with a version over one the implementation name"
+        );
+
+        Ok(())
+    }
+
+    #[test]
+    fn find_python_version_free_threaded() -> Result<()> {
+        let mut context = TestContext::new()?;
+
+        TestContext::create_mock_interpreter(
+            &context.tempdir.join("python"),
+            &PythonVersion::from_str("3.13.1").unwrap(),
+            ImplementationName::CPython,
+            true,
+            false,
+        )?;
+        TestContext::create_mock_interpreter(
+            &context.tempdir.join("python3.13t"),
+            &PythonVersion::from_str("3.13.0").unwrap(),
+            ImplementationName::CPython,
+            true,
+            true,
+        )?;
+        context.add_to_search_path(context.tempdir.to_path_buf());
+
+        let python = context.run(|| {
+            find_python_installation(
+                &PythonRequest::parse("3.13t"),
+                EnvironmentPreference::Any,
+                PythonPreference::OnlySystem,
+                &context.cache,
+            )
+        })??;
+
+        assert!(
+            matches!(
+                python,
+                PythonInstallation {
+                    source: PythonSource::SearchPath,
+                    interpreter: _
+                }
+            ),
+            "We should find a python; got {python:?}"
+        );
+        assert_eq!(
+            &python.interpreter().python_full_version().to_string(),
+            "3.13.0",
+            "We should find the correct interpreter for the request"
+        );
+        assert!(
+            &python.interpreter().gil_disabled(),
+            "We should find a python without the GIL"
+        );
+
+        Ok(())
+    }
+
+    #[test]
+    fn find_python_version_prefer_non_free_threaded() -> Result<()> {
+        let mut context = TestContext::new()?;
+
+        TestContext::create_mock_interpreter(
+            &context.tempdir.join("python"),
+            &PythonVersion::from_str("3.13.0").unwrap(),
+            ImplementationName::CPython,
+            true,
+            false,
+        )?;
+        TestContext::create_mock_interpreter(
+            &context.tempdir.join("python3.13t"),
+            &PythonVersion::from_str("3.13.0").unwrap(),
+            ImplementationName::CPython,
+            true,
+            true,
+        )?;
+        context.add_to_search_path(context.tempdir.to_path_buf());
+
+        let python = context.run(|| {
+            find_python_installation(
+                &PythonRequest::parse("3.13"),
+                EnvironmentPreference::Any,
+                PythonPreference::OnlySystem,
+                &context.cache,
+            )
+        })??;
+
+        assert!(
+            matches!(
+                python,
+                PythonInstallation {
+                    source: PythonSource::SearchPath,
+                    interpreter: _
+                }
+            ),
+            "We should find a python; got {python:?}"
+        );
+        assert_eq!(
+            &python.interpreter().python_full_version().to_string(),
+            "3.13.0",
+            "We should find the correct interpreter for the request"
+        );
+        assert!(
+            !&python.interpreter().gil_disabled(),
+            "We should prefer a python with the GIL"
+        );
+
         Ok(())
     }
 }
