@@ -65,7 +65,7 @@ impl Pep723Script {
     /// Reads a Python script and generates a default PEP 723 metadata table.
     ///
     /// See: <https://peps.python.org/pep-0723/>
-    pub async fn create(
+    pub async fn init(
         file: impl AsRef<Path>,
         requires_python: &VersionSpecifiers,
     ) -> Result<Self, Pep723Error> {
@@ -95,6 +95,51 @@ impl Pep723Script {
         })
     }
 
+    /// Create a PEP 723 script at the given path.
+    pub async fn create(
+        file: impl AsRef<Path>,
+        requires_python: &VersionSpecifiers,
+        existing_contents: Option<Vec<u8>>,
+    ) -> Result<(), Pep723Error> {
+        let file = file.as_ref();
+
+        let script_name = file
+            .file_name()
+            .and_then(|name| name.to_str())
+            .ok_or_else(|| Pep723Error::InvalidFilename(file.to_string_lossy().to_string()))?;
+
+        let default_metadata = indoc::formatdoc! {r#"
+            requires-python = "{requires_python}"
+            dependencies = []
+            "#,
+        };
+        let metadata = serialize_metadata(&default_metadata);
+
+        let script = if let Some(existing_contents) = existing_contents {
+            indoc::formatdoc! {r#"
+            {metadata}
+            {content}
+            "#,
+            content = String::from_utf8(existing_contents).map_err(|err| Pep723Error::Utf8(err.utf8_error()))?}
+        } else {
+            indoc::formatdoc! {r#"
+            {metadata}
+
+            def main() -> None:
+                print("Hello from {name}!")
+
+
+            if __name__ == "__main__":
+                main()
+        "#,
+                metadata = metadata,
+                name = script_name,
+            }
+        };
+
+        Ok(fs_err::tokio::write(file, script).await?)
+    }
+
     /// Replace the existing metadata in the file with new metadata and write the updated content.
     pub async fn write(&self, metadata: &str) -> Result<(), Pep723Error> {
         let content = format!(
@@ -161,10 +206,12 @@ pub enum Pep723Error {
     Utf8(#[from] std::str::Utf8Error),
     #[error(transparent)]
     Toml(#[from] toml::de::Error),
+    #[error("Invalid filename `{0}` supplied")]
+    InvalidFilename(String),
 }
 
 #[derive(Debug, Clone, Eq, PartialEq)]
-struct ScriptTag {
+pub struct ScriptTag {
     /// The content of the script before the metadata block.
     prelude: String,
     /// The metadata block.
@@ -202,7 +249,7 @@ impl ScriptTag {
     /// - Postlude: `import requests\n\nprint("Hello, World!")\n`
     ///
     /// See: <https://peps.python.org/pep-0723/>
-    fn parse(contents: &[u8]) -> Result<Option<Self>, Pep723Error> {
+    pub fn parse(contents: &[u8]) -> Result<Option<Self>, Pep723Error> {
         // Identify the opening pragma.
         let Some(index) = FINDER.find(contents) else {
             return Ok(None);
