@@ -1,15 +1,15 @@
 use std::{fmt::Debug, num::NonZeroUsize, path::PathBuf};
 
-use serde::{Deserialize, Serialize};
-
 use distribution_types::{FlatIndexLocation, IndexUrl, StaticMetadata};
 use install_wheel_rs::linker::LinkMode;
 use pep508_rs::Requirement;
 use pypi_types::{SupportedEnvironments, VerbatimParsedUrl};
+use serde::{Deserialize, Serialize};
+use url::Url;
 use uv_cache_info::CacheKey;
 use uv_configuration::{
     ConfigSettings, IndexStrategy, KeyringProviderType, PackageNameSpecifier, TargetTriple,
-    TrustedHost,
+    TrustedHost, TrustedPublishing,
 };
 use uv_macros::{CombineOptions, OptionsMetadata};
 use uv_normalize::{ExtraName, PackageName};
@@ -42,6 +42,9 @@ pub struct Options {
     #[serde(flatten)]
     pub top_level: ResolverInstallerOptions,
 
+    #[serde(flatten)]
+    pub publish: PublishOptions,
+
     #[option_group]
     pub pip: Option<PipOptions>,
 
@@ -1497,6 +1500,8 @@ pub struct OptionsWire {
     no_build_package: Option<Vec<PackageName>>,
     no_binary: Option<bool>,
     no_binary_package: Option<Vec<PackageName>>,
+    publish_url: Option<Url>,
+    trusted_publishing: Option<TrustedPublishing>,
 
     pip: Option<PipOptions>,
     cache_keys: Option<Vec<CacheKey>>,
@@ -1564,6 +1569,8 @@ impl From<OptionsWire> for Options {
             override_dependencies,
             constraint_dependencies,
             environments,
+            publish_url,
+            trusted_publishing,
             workspace: _,
             sources: _,
             dev_dependencies: _,
@@ -1611,6 +1618,10 @@ impl From<OptionsWire> for Options {
                 no_binary,
                 no_binary_package,
             },
+            publish: PublishOptions {
+                publish_url,
+                trusted_publishing,
+            },
             pip,
             cache_keys,
             override_dependencies,
@@ -1619,3 +1630,35 @@ impl From<OptionsWire> for Options {
         }
     }
 }
+
+#[derive(
+    Debug, Clone, Default, PartialEq, Eq, Serialize, Deserialize, CombineOptions, OptionsMetadata,
+)]
+#[serde(rename_all = "kebab-case")]
+#[cfg_attr(feature = "schemars", derive(schemars::JsonSchema))]
+pub struct PublishOptions {
+    /// The URL for publishing packages to the Python package index (by default:
+    /// <https://upload.pypi.org/legacy/>).
+    #[option(
+        default = "\"https://upload.pypi.org/legacy/\"",
+        value_type = "str",
+        example = r#"
+            publish-url = "https://test.pypi.org/legacy/"
+        "#
+    )]
+    pub publish_url: Option<Url>,
+
+    /// Configure trusted publishing via GitHub Actions.
+    ///
+    /// By default, uv checks for trusted publishing when running in GitHub Actions, but ignores it
+    /// if it isn't configured or the workflow doesn't have enough permissions (e.g., a pull request
+    /// from a fork).
+    #[option(
+        default = "automatic",
+        value_type = "str",
+        example = r#"
+            trusted-publishing = "always"
+        "#
+    )]
+    pub trusted_publishing: Option<TrustedPublishing>,
+}
