@@ -59,7 +59,7 @@ async fn do_uninstall(
     let start = std::time::Instant::now();
 
     let requests = if all {
-        vec![PythonRequest::Any]
+        vec![PythonRequest::Default]
     } else {
         let targets = targets.into_iter().collect::<BTreeSet<_>>();
         targets
@@ -82,7 +82,7 @@ async fn do_uninstall(
     let installed_installations: Vec<_> = installations.find_all()?.collect();
     let mut matching_installations = BTreeSet::default();
     for (request, download_request) in requests.iter().zip(download_requests) {
-        if matches!(requests.as_slice(), [PythonRequest::Any]) {
+        if matches!(requests.as_slice(), [PythonRequest::Default]) {
             writeln!(printer.stderr(), "Searching for Python installations")?;
         } else {
             writeln!(
@@ -100,7 +100,7 @@ async fn do_uninstall(
             matching_installations.insert(installation.clone());
         }
         if !found {
-            if matches!(requests.as_slice(), [PythonRequest::Any]) {
+            if matches!(requests.as_slice(), [PythonRequest::Default]) {
                 writeln!(printer.stderr(), "No Python installations found")?;
                 return Ok(ExitStatus::Failure);
             }
