@@ -26,7 +26,7 @@ use uv_configuration::{
     BuildOptions, Concurrency, ConfigSettings, DevMode, EditableMode, ExportFormat,
     ExtrasSpecification, HashCheckingMode, IndexStrategy, InstallOptions, KeyringProviderType,
     NoBinary, NoBuild, PreviewMode, Reinstall, SourceStrategy, TargetTriple, TrustedHost,
-    TrustedPublishing, Upgrade,
+    TrustedPublishing, Upgrade, VersionControlSystem,
 };
 use uv_normalize::PackageName;
 use uv_python::{Prefix, PythonDownloads, PythonPreference, PythonVersion, Target};
@@ -39,7 +39,7 @@ use uv_warnings::warn_user_once;
 use uv_workspace::pyproject::DependencyType;
 
 use crate::commands::ToolRunCommand;
-use crate::commands::{pip::operations::Modifications, InitProjectKind};
+use crate::commands::{pip::operations::Modifications, InitKind, InitProjectKind};
 
 /// The default publish URL.
 const PYPI_PUBLISH_URL: &str = "https://upload.pypi.org/legacy/";
@@ -158,10 +158,11 @@ impl CacheSettings {
 #[allow(clippy::struct_excessive_bools)]
 #[derive(Debug, Clone)]
 pub(crate) struct InitSettings {
-    pub(crate) path: Option<String>,
+    pub(crate) path: Option<PathBuf>,
     pub(crate) name: Option<PackageName>,
     pub(crate) package: bool,
-    pub(crate) kind: InitProjectKind,
+    pub(crate) kind: InitKind,
+    pub(crate) vcs: Option<VersionControlSystem>,
     pub(crate) no_readme: bool,
     pub(crate) no_pin_python: bool,
     pub(crate) no_workspace: bool,
@@ -180,17 +181,20 @@ impl InitSettings {
             no_package,
             app,
             lib,
+            script,
+            vcs,
             no_readme,
             no_pin_python,
             no_workspace,
             python,
         } = args;
 
-        let kind = match (app, lib) {
-            (true, false) => InitProjectKind::Application,
-            (false, true) => InitProjectKind::Library,
-            (false, false) => InitProjectKind::default(),
-            (true, true) => unreachable!("`app` and `lib` are mutually exclusive"),
+        let kind = match (app, lib, script) {
+            (true, false, false) => InitKind::Project(InitProjectKind::Application),
+            (false, true, false) => InitKind::Project(InitProjectKind::Library),
+            (false, false, true) => InitKind::Script,
+            (false, false, false) => InitKind::default(),
+            (_, _, _) => unreachable!("`app`, `lib`, and `script` are mutually exclusive"),
         };
 
         let package = flag(package || r#virtual, no_package).unwrap_or(kind.packaged_by_default());
@@ -200,6 +204,7 @@ impl InitSettings {
             name,
             package,
             kind,
+            vcs,
             no_readme,
             no_pin_python,
             no_workspace,
@@ -432,6 +437,7 @@ impl ToolInstallSettings {
 #[derive(Debug, Clone)]
 pub(crate) struct ToolUpgradeSettings {
     pub(crate) name: Vec<PackageName>,
+    pub(crate) python: Option<String>,
     pub(crate) args: ResolverInstallerOptions,
     pub(crate) filesystem: ResolverInstallerOptions,
 }
@@ -442,6 +448,7 @@ impl ToolUpgradeSettings {
     pub(crate) fn resolve(args: ToolUpgradeArgs, filesystem: Option<FilesystemOptions>) -> Self {
         let ToolUpgradeArgs {
             name,
+            python,
             all,
             mut installer,
             build,
@@ -463,6 +470,7 @@ impl ToolUpgradeSettings {
 
         Self {
             name: if all { vec![] } else { name },
+            python,
             args,
             filesystem,
         }
@@ -1663,9 +1671,11 @@ impl PipCheckSettings {
 pub(crate) struct BuildSettings {
     pub(crate) src: Option<PathBuf>,
     pub(crate) package: Option<PackageName>,
+    pub(crate) all: bool,
     pub(crate) out_dir: Option<PathBuf>,
     pub(crate) sdist: bool,
     pub(crate) wheel: bool,
+    pub(crate) build_logs: bool,
     pub(crate) build_constraint: Vec<PathBuf>,
     pub(crate) hash_checking: Option<HashCheckingMode>,
     pub(crate) python: Option<String>,
@@ -1680,6 +1690,7 @@ impl BuildSettings {
             src,
             out_dir,
             package,
+            all,
             sdist,
             wheel,
             build_constraint,
@@ -1687,6 +1698,8 @@ impl BuildSettings {
             no_require_hashes,
             verify_hashes,
             no_verify_hashes,
+            build_logs,
+            no_build_logs,
             python,
             build,
             refresh,
@@ -1696,9 +1709,11 @@ impl BuildSettings {
         Self {
             src,
             package,
+            all,
             out_dir,
             sdist,
             wheel,
+            build_logs: flag(build_logs, no_build_logs).unwrap_or(true),
             build_constraint: build_constraint
                 .into_iter()
                 .filter_map(Maybe::into_option)
