@@ -1,9 +1,12 @@
 #![cfg(all(feature = "python", feature = "pypi"))]
 
+use std::process::Command;
+
 use anyhow::Result;
 use assert_fs::prelude::*;
 use indoc::indoc;
 use insta::assert_snapshot;
+use predicates::prelude::predicate;
 
 use common::{uv_snapshot, TestContext};
 
@@ -401,6 +404,201 @@ fn init_library() -> Result<()> {
     Ok(())
 }
 
+// General init --script correctness test
+#[test]
+fn init_script() -> Result<()> {
+    let context = TestContext::new("3.12");
+
+    let child = context.temp_dir.child("foo");
+    child.create_dir_all()?;
+
+    let script = child.join("hello.py");
+
+    uv_snapshot!(context.filters(), context.init().current_dir(&child).arg("--script").arg("hello.py"), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Initialized script at `hello.py`
+    "###);
+
+    let script = fs_err::read_to_string(&script)?;
+    insta::with_settings!({
+        filters => context.filters(),
+    }, {
+        assert_snapshot!(
+            script, @r###"
+        # /// script
+        # requires-python = ">=3.12"
+        # dependencies = []
+        # ///
+
+
+        def main() -> None:
+            print("Hello from hello.py!")
+
+
+        if __name__ == "__main__":
+            main()
+        "###
+        );
+    });
+
+    uv_snapshot!(context.filters(), context.run().current_dir(&child).arg("python").arg("hello.py"), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    Hello from hello.py!
+
+    ----- stderr -----
+    "###);
+
+    Ok(())
+}
+
+// Ensure python versions passed as arguments are present in file metadata
+#[test]
+fn init_script_python_version() -> Result<()> {
+    let context = TestContext::new("3.11");
+
+    let child = context.temp_dir.child("foo");
+    child.create_dir_all()?;
+
+    let script = child.join("version.py");
+
+    uv_snapshot!(context.filters(), context.init().current_dir(&child).arg("--script").arg("version.py").arg("--python").arg("3.11"), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Initialized script at `version.py`
+    "###);
+
+    let script = fs_err::read_to_string(&script)?;
+    insta::with_settings!({
+        filters => context.filters(),
+    }, {
+        assert_snapshot!(
+            script, @r###"
+        # /// script
+        # requires-python = ">=3.11"
+        # dependencies = []
+        # ///
+
+
+        def main() -> None:
+            print("Hello from version.py!")
+
+
+        if __name__ == "__main__":
+            main()
+        "###
+        );
+    });
+
+    Ok(())
+}
+
+// Init script should create parent directories if they don't exist
+#[test]
+fn init_script_create_directory() -> Result<()> {
+    let context = TestContext::new("3.12");
+
+    let child = context.temp_dir.child("foo");
+    child.create_dir_all()?;
+
+    let script = child.join("test").join("dir.py");
+
+    uv_snapshot!(context.filters(), context.init().current_dir(&child).arg("--script").arg("test/dir.py"), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Initialized script at `test/dir.py`
+    "###);
+
+    let script = fs_err::read_to_string(&script)?;
+    insta::with_settings!({
+        filters => context.filters(),
+    }, {
+        assert_snapshot!(
+            script, @r###"
+        # /// script
+        # requires-python = ">=3.12"
+        # dependencies = []
+        # ///
+
+
+        def main() -> None:
+            print("Hello from dir.py!")
+
+
+        if __name__ == "__main__":
+            main()
+        "###
+        );
+    });
+
+    Ok(())
+}
+
+// Init script should fail if file is already a PEP 723 script
+#[test]
+fn init_script_file_conflicts() -> Result<()> {
+    let context = TestContext::new("3.12");
+
+    let child = context.temp_dir.child("foo");
+    child.create_dir_all()?;
+
+    uv_snapshot!(context.filters(), context.init().current_dir(&child).arg("--script").arg("name_conflict.py"), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Initialized script at `name_conflict.py`
+    "###);
+
+    uv_snapshot!(context.filters(), context.init().current_dir(&child).arg("--script").arg("name_conflict.py"), @r###"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+
+    ----- stderr -----
+    error: `name_conflict.py` is already a PEP 723 script; use `uv run` to execute it
+    "###);
+
+    let contents = "print(\"Hello, world!\")";
+    fs_err::write(child.join("existing_script.py"), contents)?;
+
+    uv_snapshot!(context.filters(), context.init().current_dir(&child).arg("--script").arg("existing_script.py"), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Initialized script at `existing_script.py`
+    "###);
+
+    let existing_script = fs_err::read_to_string(child.join("existing_script.py"))?;
+
+    assert_snapshot!(
+        existing_script, @r###"
+    # /// script
+    # requires-python = ">=3.12"
+    # dependencies = []
+    # ///
+
+    print("Hello, world!")
+    "###
+    );
+
+    Ok(())
+}
+
 /// Run `uv init --lib` with an existing py.typed file
 #[test]
 fn init_py_typed_exists() -> Result<()> {
@@ -1936,3 +2134,129 @@ fn init_failure() -> Result<()> {
 
     Ok(())
 }
+
+#[test]
+fn init_git() -> Result<()> {
+    let context = TestContext::new("3.12");
+
+    let child = context.temp_dir.child("foo");
+
+    uv_snapshot!(context.filters(), context.init().arg(child.as_ref()), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Initialized project `foo` at `[TEMP_DIR]/foo`
+    "###);
+
+    let gitignore = fs_err::read_to_string(child.join(".gitignore"))?;
+    insta::with_settings!({
+        filters => context.filters(),
+    }, {
+        assert_snapshot!(
+            gitignore, @r###"
+        # Python-generated files
+        __pycache__/
+        *.py[oc]
+        build/
+        dist/
+        wheels/
+        *.egg-info
+
+        # Virtual environments
+        .venv
+        "###
+        );
+    });
+
+    child.child(".git").assert(predicate::path::is_dir());
+
+    Ok(())
+}
+
+#[test]
+fn init_vcs_none() {
+    let context = TestContext::new("3.12");
+
+    let child = context.temp_dir.child("foo");
+
+    uv_snapshot!(context.filters(), context.init().arg(child.as_ref()).arg("--vcs").arg("none"), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Initialized project `foo` at `[TEMP_DIR]/foo`
+    "###);
+
+    child.child(".gitignore").assert(predicate::path::missing());
+    child.child(".git").assert(predicate::path::missing());
+}
+
+/// Run `uv init` from within a Git repository. Do not try to reinitialize one.
+#[test]
+fn init_inside_git_repo() -> Result<()> {
+    let context = TestContext::new("3.12");
+
+    Command::new("git")
+        .arg("init")
+        .current_dir(&context.temp_dir)
+        .status()?;
+
+    let child = context.temp_dir.child("foo");
+
+    uv_snapshot!(context.filters(), context.init().arg(child.as_ref()).arg("--vcs").arg("git"), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Initialized project `foo` at `[TEMP_DIR]/foo`
+    "###);
+
+    child.child(".gitignore").assert(predicate::path::missing());
+
+    let child = context.temp_dir.child("bar");
+    uv_snapshot!(context.filters(), context.init().arg(child.as_ref()), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Initialized project `bar` at `[TEMP_DIR]/bar`
+    "###);
+
+    child.child(".gitignore").assert(predicate::path::missing());
+
+    Ok(())
+}
+
+#[test]
+fn init_git_not_installed() {
+    let context = TestContext::new("3.12");
+
+    let child = context.temp_dir.child("foo");
+
+    // Without explicit `--vcs git`, `uv init` succeeds without initializing a Git repository.
+    uv_snapshot!(context.filters(), context.init().env("PATH", &*child).arg(child.as_ref()), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Initialized project `foo` at `[TEMP_DIR]/foo`
+    "###);
+
+    // With explicit `--vcs git`, `uv init` will fail.
+    let child = context.temp_dir.child("bar");
+    // Set `PATH` to child to make `git` command cannot be found.
+    uv_snapshot!(context.filters(), context.init().env("PATH", &*child).arg(child.as_ref()).arg("--vcs").arg("git"), @r###"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+
+    ----- stderr -----
+    error: Attempted to initialize a Git repository, but `git` was not found in PATH
+    "###);
+}
